# Sci::Signal

信号処理ライブラリ (作りかけ) 。

現在、MatLab でいうところの
- butter()
- filtfilt() **依存あり**
が利用可能。

## Installation

> Gemfile へ追加

```ruby
gem 'sci-signal'
```

> その後、実行

    $ bundle install

> 自身の端末にインストールする場合

    $ gem install sci-signal

## Example

```ruby
require "sci/signal"
require "csv"

include Sci::Signal
include Numo

# フィルター関数の設定
# フィルター関数は MatLab (Octave) の `filter` と互換性のある関数
Sci::Signal.filter_function = <他のモジュール or クラス>.method(:filter)

# 観測データ生成
fs = 1000
t = DFloat[0...1000] / fs
noise = DFloat.new(t.size).rand_norm(0, 0.25)
x = NMath.sin(2 * Math::PI * t * 10) + noise

# Butterworth バンドパスフィルター処理
b, a = butter(3, DFloat[5, 15] / fs * 2, ftype: "bandpass")
y = Sci::Signal.filtfilt(b, a, x)


# データ保存
data = DFloat.cast([t, x, y]).transpose.to_a
csv_str = CSV.generate("", :col_sep => " ") do |csv|
    data.each do |line|
        csv << line
    end
end
open("data", "w") do |f|
    f.puts csv_str
end
```

![Butterworth フィルター](https://user-images.githubusercontent.com/39254183/131601461-352cc7a4-d269-480d-a354-470cd681c1f3.png)


## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/himeyama/sci-signal.
